##  Subscription Role
Subscription roles are created by admins to mirror your organization's governance structure on a one-to-one basis. They allow you to subscribe to fact sheets with specific roles that closely align with your organizational hierarchy, such as Application Owner, Project Manager, Data Architect, etc. These roles make it easy to identify and notify the right people and ensure responsibilities are consistently assigned without confusion and overlap.
Creating a subscription role involves specifying the subscription type for that role, specifying the relevant fact sheet types it applies to, and providing a clear name and description. To learn more, see [Creating a Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD#loio275af3a27a4410148eada5eb5d54814b__creating_a_subscription_role).
